@@ -9,31 +9,36 @@ utils::globalVariables(c(
   opts.Require <- RequireOptions()
   toset <- !(names(opts.Require) %in% names(opts))
   if (any(toset)) options(opts.Require[toset])
-  if (!is.null(getOption("Require.RPackageCache")))
-    checkPath(rpackageFolder(getOption("Require.RPackageCache")), create = TRUE)
 
   if (getOption("Require.persistentPkgEnv")) {
-    if (file.exists(.thePersistentFile)) {
-      pkgEnvLast <- readRDS(.thePersistentFile)
+    if (file.exists(.thePersistentFile())) {
+      pkgEnvLast <- readRDS(.thePersistentFile())
       list2env(pkgEnvLast, .pkgEnv)
     }
   }
+
   invisible()
 }
 
 .onAttach <- function(libname, pkgname) {
   if (isInteractive()) {
-    mess <- c("Require version: ", as.character(utils::packageVersion("Require")), ". ")
-    mess <- c(mess, "See ?RequireOptions for additional settings.")
+    mess <- c(
+      "Require version: ", as.character(utils::packageVersion("Require")), ".\n",
+      "  Using cache directory: ", RequireCacheDir(), ".\n",
+      "  See ?RequireOptions for additional settings."
+    )
+
     packageStartupMessage(mess)
   }
 }
 
 .onUnload <- function(libpath) {
   if (getOption("Require.persistentPkgEnv")) {
-    pkgEnvLast <- as.list(.pkgEnv); 
-    saveRDS(pkgEnvLast, file = .thePersistentFile)
+    pkgEnvLast <- as.list(.pkgEnv);
+    saveRDS(pkgEnvLast, file = .thePersistentFile())
   }
 }
 
-.thePersistentFile <- file.path("~", "._Require_pkgEnv.rdata")
\ No newline at end of file
+.thePersistentFile <- function() {
+  file.path(RequireCacheDir(), "pkgEnv.Rdata")
+}
